==> axyl-lucene_2.1.4.tar.gz: axyl-lucene-2.1.4/luceneserver/src/nz/net/catalyst/lucene/server/SocketAction.java <==
/** *********************************************************************
 * Copyright (C) 2003 Catalyst IT                                       *
 *                                                                      *
 * This program is free software; you can redistribute it and/or modify *
 * it under the terms of the GNU General Public License as published by *
 * the Free Software Foundation; either version 2 of the License, or    *
 * (at your option) any later version.                                  *
 *                                                                      *
 * This program is distributed in the hope that it will be useful,      *
 * but WITHOUT ANY WARRANTY; without even the implied warranty of       *
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the        *
 * GNU General Public License for more details.                         *
 *                                                                      *
 * You should have received a copy of the GNU General Public License    *
 * along with this program; if not, write to:                           *
 *   The Free Software Foundation, Inc., 59 Temple Place, Suite 330,    *
 *   Boston, MA  02111-1307  USA                                        *
 ************************************************************************/
package nz.net.catalyst.lucene.server;

import java.io.BufferedOutputStream;
import java.io.BufferedReader;
import java.io.IOException;
import java.io.InputStreamReader;
import java.io.PrintWriter;
import java.net.Socket;

import nz.net.catalyst.RtException;
import nz.net.catalyst.Util;

import com.holub.asynch.Socket_server;

/**
 * Experimental class.
 * <br>
 * Not not used.
 * 
 * @deprecated
 * @author hamish
 */
public class SocketAction implements Socket_server.Client_action {
    
    
    public void action( Socket socketClient)
    {
          try
          {
              //these lines added by hamish to try and simplify things.
              String name = Util.name(socketClient);
              try
              {
                //BufferedReader input = getBufferedReader(socketClient.getInputStream());
                //PrintWriter output = getPrintWriter(socketClient.getOutputStream());

                new nz.net.catalyst.lucene.server.Session().communicate(
                        new BufferedReader(new InputStreamReader(socketClient.getInputStream(), "UTF-8")),
                        new PrintWriter(new BufferedOutputStream(socketClient.getOutputStream())),
                        name);
                                            //input, output, name);

                //input.close();
                //output.close();
                socketClient.close();
              }
              catch (IOException e)
              {
                throw new RtException("Error initialising new client connection " + name, e);
              }              
              //end added by hamish.    
          
          }
          finally
          {
            try
            {
              socketClient.close();
            }
            catch (IOException e)
            {
              // Ignore
            }
          }        
    }
    
    
};

==> axyl-lucene_2.1.8.tar.gz: axyl-lucene-2.1.8/luceneserver/src/nz/net/catalyst/lucene/server/SocketAction.java <==
/** *********************************************************************
 * Copyright (C) 2003 Catalyst IT                                       *
 *                                                                      *
 * This program is free software; you can redistribute it and/or modify *
 * it under the terms of the GNU General Public License as published by *
 * the Free Software Foundation; either version 2 of the License, or    *
 * (at your option) any later version.                                  *
 *                                                                      *
 * This program is distributed in the hope that it will be useful,      *
 * but WITHOUT ANY WARRANTY; without even the implied warranty of       *
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the        *
 * GNU General Public License for more details.                         *
 *                                                                      *
 * You should have received a copy of the GNU General Public License    *
 * along with this program; if not, write to:                           *
 *   The Free Software Foundation, Inc., 59 Temple Place, Suite 330,    *
 *   Boston, MA  02111-1307  USA                                        *
 ************************************************************************/
package nz.net.catalyst.lucene.server;

import java.io.BufferedOutputStream;
import java.io.BufferedReader;
import java.io.IOException;
import java.io.InputStreamReader;
import java.io.PrintWriter;
import java.net.Socket;

import nz.net.catalyst.Util;

import com.holub.asynch.Socket_server;

/**
 * Experimental class.
 * <br>
 * Not not used.
 * 
 * @deprecated
 * @author hamish
 */
public class SocketAction implements Socket_server.Client_action {
    
    
    public void action( Socket socketClient)
    {
          try
          {
              //these lines added by hamish to try and simplify things.
              String name = Util.name(socketClient);
              try
              {
                //BufferedReader input = getBufferedReader(socketClient.getInputStream());
                //PrintWriter output = getPrintWriter(socketClient.getOutputStream());

                new nz.net.catalyst.lucene.server.Session().communicate(
                        new BufferedReader(new InputStreamReader(socketClient.getInputStream(), "UTF-8")),
                        new PrintWriter(new BufferedOutputStream(socketClient.getOutputStream())),
                        name);
                                            //input, output, name);

                //input.close();
                //output.close();
                socketClient.close();
              }
              catch (IOException e)
              {
                throw new RuntimeException("Error initialising new client connection " + name, e);
              }              
              //end added by hamish.    
          
          }
          finally
          {
            try
            {
              socketClient.close();
            }
            catch (IOException e)
            {
              // Ignore
            }
          }        
    }
    
    
};
